# psiaudio

Tools for auditory signal generation and processing. Provides:

* Finite and infinite signal generation support
* Calibration
* Data processing pipelines using coroutines
* Basic utility functions common to auditory processing

# Contributors and Acknowledgements

* Brad Buran (New York University, Oregon Health & Science University)
* Decibel Therapeutics, Inc.

Work on psiaudio was supported by grants R01-DC009237 and R21-DC016969 from the National Institute on Deafness and Other Communication Disorders and an Emerging Research Grant from the Hearing Health Foundation.
